@@ -14,8 +14,9 @@ class Task:
 
     def __init__(self, uuid: str, name: str, product_uuid: str, pose: Pose, automated: bool = False,
                  assigned_to: str = ASSIGNED_TO_HUMAN, conditions: List[str] = None, conditions_fulfilled: bool = True,
-                 description: str = "", status: str = STATUS_WAITING, _type: str = ''):
+                 description: str = "", status: str = '', _type: str = ''):
         conditions = conditions if conditions else []
+        status = status if status else self.STATUS_MISSING_PRECONDITION if len(conditions) > 0 else self.STATUS_WAITING
         assert type(uuid) == str
         assert type(name) == str
         assert type(product_uuid) == str
@@ -59,3 +60,22 @@ class Task:
         return f"<uuid={self.uuid},name={self.name},product_uuid={self.product_uuid},pose={self.pose}," \
                f"automated={self.automated},assigned_to={self.assigned_to},conditions={self.conditions}," \
                f"status={self.status},conditions_fulfilled={self.conditions_fulfilled},description={self.description}>"
+
+
+class TaskMessage:
+
+    def __init__(self, task_uuid: str, message: str, _type: str = ''):
+        self._type = 'task_message'
+        self.task_uuid = task_uuid
+        self.message = message
+
+    def __eq__(self, other: object) -> bool:
+        if isinstance(other, TaskMessage):
+            return other.task_uuid == self.task_uuid and other.message == self.message
+        return False
+
+    def __ne__(self, other: object) -> bool:
+        return not self.__eq__(other)
+
+    def __repr__(self):
+        return f"<task_uuid={self.task_uuid},message={self.message}>"
